import os
import urllib
import urllib.error

__package__ = "reposcraping"
RepoScraping = __import__("reposcraping").RepoScraping


class Cloner(object):
    def __init__(self, scraping: RepoScraping) -> None:
        self.scraping: RepoScraping = scraping

    def clone(
        self,
        paths: dict,
        only_file_name: bool = False,
        p: bool = False
    ) -> None:

        for i in paths:
            path = paths[i]
            if not os.path.isdir(path):
                os.makedirs(path, exist_ok=True)

        for url in self.scraping.file_urls:
            url = (
                url
                .replace("github.com", "raw.githubusercontent.com")
                .replace("blob/", "")
            )

            if only_file_name:
                file_name = url.split("/")[-1]
            else:
                file_name = "_".join(url.split("/")[3:]).replace("_master", "")

            path = self.__get_path_by_extension(paths, file_name)
            if not path:
                continue

            full_path = os.path.join(path, file_name)

            if os.path.isfile(full_path):
                continue

            try:
                if p:
                    print(full_path)
                urllib.request.urlretrieve(url, full_path)
            except urllib.error.HTTPError:
                pass

    def __get_path_by_extension(self, paths: dict, file_name: str) -> str:
        if paths:
            for i in paths:
                if file_name.endswith(i):
                    return paths[i]
        return None



from setuptools import setup, find_packages
import codecs

with codecs.open("README.md", "r", "utf-8") as f:
    long_description = f.read()

setup(
    name='reposcraping',
    version='1.1.6',
    description='Scraping GitHub repository',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='emresvd',
    license='MIT',
    url='https://github.com/emresvd/reposcraping',
    packages=find_packages(
        exclude=[
            'files',
        ],
    ),
    install_requires=[
        'beautifulsoup4==4.11.1',
        'requests==2.28.1',
    ],
    keywords=[
        'github',
        'scraping',
        'repository',
        'clone',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
        "Operating System :: OS Independent",
    ],
)



from bs4 import BeautifulSoup
import requests
from urllib.parse import urljoin


class RepoScraping(object):
    def __init__(self, repo_url: str, p: bool = False) -> None:
        self.repo_url = repo_url
        self.p = p

        self.tree_urls = [self.repo_url]
        self.file_urls = []

        self.__prepare_tree_urls()
        self.__prepare_file_urls()

    def __prepare_tree_urls(self) -> None:
        for i in self.tree_urls:
            r = requests.get(i)
            soup = BeautifulSoup(r.content, 'html.parser')

            for j in soup.find_all('a'):
                try:
                    if "tree/master" in j.get('href'):
                        url = urljoin(self.repo_url, j.get('href'))
                        if url not in self.tree_urls:
                            self.tree_urls.append(url)
                            if self.p:
                                print(url)
                except TypeError:
                    pass

    def __prepare_file_urls(self) -> None:
        for tree_url in self.tree_urls:
            r = requests.get(tree_url)
            soup = BeautifulSoup(r.content, 'html.parser')

            for i in soup.find_all('a'):
                try:
                    if "blob/master" in i.get('href'):
                        url = urljoin(self.repo_url, i.get('href'))
                        if url not in self.file_urls:
                            self.file_urls.append(url)
                            if self.p:
                                print(url)
                except TypeError:
                    pass
